ImageData class

Constructors

ImageData(String fileName, String filePath, {String? uniqueId, String? imageUploadFolder})
ImageData.fromJson(Map<String, dynamic> json)
ImageData.fromMap(LinkedHashMap<Object?, Object?> map)

Properties

amazonUrl ↔ String?
getter/setter pair
fileName ↔ String
getter/setter pair
filePath ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
imageUploadFolder ↔ String?
getter/setter pair
isUploadError ↔ bool
getter/setter pair
progress ↔ double?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state ↔ String?
getter/setter pair
uniqueId ↔ String?
getter/setter pair

Methods

copy(ImageData another) → void
initFromMap(LinkedHashMap<Object?, Object?> map) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited